==> gnubiff_2.0.3.orig.tar.gz: gnubiff-2.0.3/src/maildir.h <==
// ========================================================================
// gnubiff -- a mail notification program
// Copyright (c) 2000-2004 Nicolas Rougier
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// ========================================================================
//
// File          : $RCSfile: maildir.h,v $
// Revision      : $Revision: 1.1 $
// Revision date : $Date: 2004/10/06 13:21:57 $
// Author(s)     : Nicolas Rougier
// Short         : 
//
// This file is part of gnubiff.
//
// -*- mode:C++; tab-width:4; c-basic-offset:4; indent-tabs-mode:nil -*-
// ========================================================================

#ifndef __MAILDIR_H__
#define __MAILDIR_H__

#include "mailbox.h"
#include <time.h>


class Maildir : public Mailbox {
private:
	time_t 			last_mtime_;		// last modification time of directory 'new'

public:
	/* base */
	Maildir (class Biff *biff);
	Maildir (const Mailbox &other);
	~Maildir (void);

	/* mailbox inherited methods */
	void get_status (void);
	void get_header (void);
};

#endif

==> gnubiff-2.1.3.tar.gz: gnubiff-2.1.3/src/maildir.h <==
// ========================================================================
// gnubiff -- a mail notification program
// Copyright (c) 2000-2004 Nicolas Rougier
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// ========================================================================
//
// File          : $RCSfile: maildir.h,v $
// Revision      : $Revision: 1.2 $
// Revision date : $Date: 2004/12/03 17:13:39 $
// Author(s)     : Nicolas Rougier
// Short         : 
//
// This file is part of gnubiff.
//
// -*- mode:C++; tab-width:4; c-basic-offset:4; indent-tabs-mode:nil -*-
// ========================================================================

#ifndef __MAILDIR_H__
#define __MAILDIR_H__

#include "local.h"
#include <time.h>


class Maildir : public Local {

public:
	// ========================================================================
	//  base
	// ========================================================================	
	Maildir (class Biff *biff);
	Maildir (const Mailbox &other);
	~Maildir (void);

	// ========================================================================
	//  main
	// ========================================================================	
	void fetch (void);
};

#endif
